http://macieira.org/~thiago/qt-5.3/QtWidgets.diff
diff --git a/src/widgets/dialogs/qwizard.h b/src/widgets/dialogs/qwizard.h
index 9dea9a8..51b18e0 100644
--- a/src/widgets/dialogs/qwizard.h
+++ b/src/widgets/dialogs/qwizard.h
@@ -115,7 +115,8 @@ public:
         HelpButtonOnRight               = 0x00001000,
         HaveCustomButton1               = 0x00002000,
         HaveCustomButton2               = 0x00004000,
-        HaveCustomButton3               = 0x00008000
+        HaveCustomButton3               = 0x00008000,
+        NoCancelButtonOnLastPage        = 0x00010000
     };
 
     Q_DECLARE_FLAGS(WizardOptions, WizardOption)
diff --git a/src/widgets/kernel/qapplication.h b/src/widgets/kernel/qapplication.h
index 83673ee..e72fe29 100644
--- a/src/widgets/kernel/qapplication.h
+++ b/src/widgets/kernel/qapplication.h
@@ -112,7 +112,7 @@ public:
     QT_DEPRECATED static inline void setGraphicsSystem(const QString &) {}
 #endif
 
-#ifdef Q_NO_USING_KEYWORD
+#if defined(Q_NO_USING_KEYWORD) && !defined(Q_QDOC)
     static QPalette palette() { return QGuiApplication::palette(); }
 #else
     using QGuiApplication::palette;
@@ -126,10 +126,10 @@ public:
     static void setFont(const QFont &, const char* className = 0);
     static QFontMetrics fontMetrics();
 
+#if QT_VERSION < 0x060000 // remove these forwarders in Qt 6
     static void setWindowIcon(const QIcon &icon);
     static QIcon windowIcon();
-
-
+#endif
 
     static QWidgetList allWidgets();
     static QWidgetList topLevelWidgets();
diff --git a/src/widgets/styles/qstyle.h b/src/widgets/styles/qstyle.h
index bbb216b..136daa9 100644
--- a/src/widgets/styles/qstyle.h
+++ b/src/widgets/styles/qstyle.h
@@ -702,6 +702,7 @@ public:
         SH_ToolTip_FallAsleepDelay,
         SH_Widget_Animate,
         SH_Splitter_OpaqueResize,
+        SH_ComboBox_UseNativePopup,
         // Add new style hint values here
 
         SH_CustomBase = 0xf0000000
diff --git a/src/widgets/widgets/qabstractspinbox.h b/src/widgets/widgets/qabstractspinbox.h
index 4f6aad0..7989000 100644
--- a/src/widgets/widgets/qabstractspinbox.h
+++ b/src/widgets/widgets/qabstractspinbox.h
@@ -72,6 +72,7 @@ class Q_WIDGETS_EXPORT QAbstractSpinBox : public QWidget
     Q_PROPERTY(CorrectionMode correctionMode READ correctionMode WRITE setCorrectionMode)
     Q_PROPERTY(bool acceptableInput READ hasAcceptableInput)
     Q_PROPERTY(bool keyboardTracking READ keyboardTracking WRITE setKeyboardTracking)
+    Q_PROPERTY(bool showGroupSeparator READ isGroupSeparatorShown WRITE setGroupSeparatorShown)
 public:
     explicit QAbstractSpinBox(QWidget *parent = 0);
     ~QAbstractSpinBox();
@@ -114,6 +115,9 @@ public:
     void setAccelerated(bool on);
     bool isAccelerated() const;
 
+    void setGroupSeparatorShown(bool shown);
+    bool isGroupSeparatorShown() const;
+
     QSize sizeHint() const;
     QSize minimumSizeHint() const;
     void interpretText();
diff --git a/src/widgets/widgets/qdialogbuttonbox.h b/src/widgets/widgets/qdialogbuttonbox.h
index d8e1a99..5cd94f8 100644
--- a/src/widgets/widgets/qdialogbuttonbox.h
+++ b/src/widgets/widgets/qdialogbuttonbox.h
@@ -61,7 +61,7 @@ class Q_WIDGETS_EXPORT QDialogButtonBox : public QWidget
 
 public:
     enum ButtonRole {
-        // keep this in sync with QMessageBox::ButtonRole
+        // keep this in sync with QMessageBox::ButtonRole and QPlatformDialogHelper::ButtonRole
         InvalidRole = -1,
         AcceptRole,
         RejectRole,
@@ -77,7 +77,7 @@ public:
     };
 
     enum StandardButton {
-        // keep this in sync with QMessageBox::StandardButton
+        // keep this in sync with QMessageBox::StandardButton and QPlatformDialogHelper::StandardButton
         NoButton           = 0x00000000,
         Ok                 = 0x00000400,
         Save               = 0x00000800,
@@ -107,6 +107,7 @@ public:
     Q_DECLARE_FLAGS(StandardButtons, StandardButton)
 
     enum ButtonLayout {
+        // keep this in sync with QMessageBox::ButtonLayout and QPlatformDialogHelper::ButtonLayout
         WinLayout,
         MacLayout,
         KdeLayout,
diff --git a/src/widgets/widgets/qlcdnumber.h b/src/widgets/widgets/qlcdnumber.h
index 3dde152..ba7b2d8 100644
--- a/src/widgets/widgets/qlcdnumber.h
+++ b/src/widgets/widgets/qlcdnumber.h
@@ -43,7 +43,6 @@
 #define QLCDNUMBER_H
 
 #include <QtWidgets/qframe.h>
-#include <QtCore/qbitarray.h>
 
 QT_BEGIN_NAMESPACE
 
diff --git a/src/widgets/widgets/qmenu.h b/src/widgets/widgets/qmenu.h
index 7a128e8..8a8eaf3 100644
--- a/src/widgets/widgets/qmenu.h
+++ b/src/widgets/widgets/qmenu.h
@@ -140,6 +140,7 @@ public:
 
     void setNoReplayFor(QWidget *widget);
     QPlatformMenu *platformMenu();
+    void setPlatformMenu(QPlatformMenu *platformMenu);
 
 #ifdef Q_OS_WINCE
     HMENU wceMenu();
diff --git a/src/widgets/widgets/qplaintextedit.h b/src/widgets/widgets/qplaintextedit.h
index 8154881..54cd3e1 100644
--- a/src/widgets/widgets/qplaintextedit.h
+++ b/src/widgets/widgets/qplaintextedit.h
@@ -83,6 +83,7 @@ class Q_WIDGETS_EXPORT QPlainTextEdit : public QAbstractScrollArea
     Q_PROPERTY(int maximumBlockCount READ maximumBlockCount WRITE setMaximumBlockCount)
     Q_PROPERTY(bool backgroundVisible READ backgroundVisible WRITE setBackgroundVisible)
     Q_PROPERTY(bool centerOnScroll READ centerOnScroll WRITE setCenterOnScroll)
+    Q_PROPERTY(QString placeholderText READ placeholderText WRITE setPlaceholderText)
 public:
     enum LineWrapMode {
         NoWrap,
@@ -96,6 +97,9 @@ public:
     void setDocument(QTextDocument *document);
     QTextDocument *document() const;
 
+    void setPlaceholderText(const QString &placeholderText);
+    QString placeholderText() const;
+
     void setTextCursor(const QTextCursor &cursor);
     QTextCursor textCursor() const;
 
@@ -141,6 +145,9 @@ public:
     bool centerOnScroll() const;
 
     bool find(const QString &exp, QTextDocument::FindFlags options = 0);
+#ifndef QT_NO_REGEXP
+    bool find(const QRegExp &exp, QTextDocument::FindFlags options = 0);
+#endif
 
     inline QString toPlainText() const
     { return document()->toPlainText(); }
@@ -178,6 +185,7 @@ public:
 
     int blockCount() const;
     QVariant inputMethodQuery(Qt::InputMethodQuery property) const;
+    Q_INVOKABLE QVariant inputMethodQuery(Qt::InputMethodQuery query, QVariant argument) const;
 
 public Q_SLOTS:
 
diff --git a/src/widgets/widgets/qtextedit.h b/src/widgets/widgets/qtextedit.h
index 06ec5fb..a283a51 100644
--- a/src/widgets/widgets/qtextedit.h
+++ b/src/widgets/widgets/qtextedit.h
@@ -162,6 +162,9 @@ public:
     void setWordWrapMode(QTextOption::WrapMode policy);
 
     bool find(const QString &exp, QTextDocument::FindFlags options = 0);
+#ifndef QT_NO_REGEXP
+    bool find(const QRegExp &exp, QTextDocument::FindFlags options = 0);
+#endif
 
     QString toPlainText() const;
 #ifndef QT_NO_TEXTHTMLPARSER
@@ -209,6 +212,7 @@ public:
     void print(QPagedPaintDevice *printer) const;
 
     QVariant inputMethodQuery(Qt::InputMethodQuery property) const;
+    Q_INVOKABLE QVariant inputMethodQuery(Qt::InputMethodQuery query, QVariant argument) const;
 
 public Q_SLOTS:
     void setFontPointSize(qreal s);
_______________________________________________
Development mailing list
Development@qt-project.org
http://lists.qt-project.org/mailman/listinfo/development

Reply via email to
diff --git a/src/widgets/dialogs/qmessagebox.h b/src/widgets/dialogs/qmessagebox.h
index c5598a8..5fae174 100644
--- a/src/widgets/dialogs/qmessagebox.h
+++ b/src/widgets/dialogs/qmessagebox.h
@@ -72,6 +72,7 @@ class Q_WIDGETS_EXPORT QMessageBox : public QDialog
 
 public:
     enum Icon {
+        // keep this in sync with QMessageDialogOptions::Icon
         NoIcon = 0,
         Information = 1,
         Warning = 2,
@@ -80,7 +81,7 @@ public:
     };
 
     enum ButtonRole {
         // keep this in sync with QDialogButtonBox::ButtonRole
         InvalidRole = -1,
         AcceptRole,
         RejectRole,
@@ -96,7 +97,7 @@ public:
     };
 
     enum StandardButton {
         // keep this in sync with QDialogButtonBox::StandardButton and QMessageDialogOptions::StandardButton
         NoButton           = 0x00000000,
         Ok                 = 0x00000400,
         Save               = 0x00000800,
@@ -309,7 +310,7 @@ protected:
 
 private:
     Q_PRIVATE_SLOT(d_func(), void _q_buttonClicked(QAbstractButton *))
-    Q_PRIVATE_SLOT(d_func(), void _q_clicked(QMessageDialogOptions::StandardButton, QMessageDialogOptions::ButtonRole))
+    Q_PRIVATE_SLOT(d_func(), void _q_clicked(QPlatformDialogHelper::StandardButton, QPlatformDialogHelper::ButtonRole))
 
     Q_DISABLE_COPY(QMessageBox)
     Q_DECLARE_PRIVATE(QMessageBox)
@@ -80,7 +81,7 @@ public:
 
     enum ButtonRole {
-        // keep this in sync with QDialogButtonBox::ButtonRole
+        // keep this in sync with QDialogButtonBox::ButtonRole and QPlatformDialogHelper::ButtonRole
         InvalidRole = -1,
         AcceptRole,
@@ -96,7 +97,7 @@ public:
 
     enum StandardButton {
-        // keep this in sync with QDialogButtonBox::StandardButton and QMessageDialogOptions::StandardButton
+        // keep this in sync with QDialogButtonBox::StandardButton and QPlatformDialogHelper::StandardButton
         NoButton           = 0x00000000,
         Ok                 = 0x00000400,